@@ -1,27 +1,13 @@
 /*
-    Copyright 2009 Will Stephenson <wstephenson@kde.org>
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2009 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2014 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include "debug.h"
 #include "modemmonitor.h"
+#include "debug.h"
 
 #include <QDBusPendingReply>
 
@@ -30,8 +16,8 @@
 #include <KMessageBox>
 #include <KSharedConfig>
 
-#include <NetworkManagerQt/Device>
 #include <NetworkManagerQt/Connection>
+#include <NetworkManagerQt/Device>
 #include <NetworkManagerQt/GsmSetting>
 #include <NetworkManagerQt/Manager>
 
@@ -47,8 +33,9 @@ public:
     QPointer<PinDialog> dialog;
 };
 
-ModemMonitor::ModemMonitor(QObject * parent)
-    :QObject(parent), d_ptr(new ModemMonitorPrivate)
+ModemMonitor::ModemMonitor(QObject *parent)
+    : QObject(parent)
+    , d_ptr(new ModemMonitorPrivate)
 {
     Q_D(ModemMonitor);
     d->dialog.clear();
@@ -91,8 +78,7 @@ void ModemMonitor::unlockModem(const QString &modemUni)
 
     if (modem) {
         // Using queued invocation to prevent kded stalling here until user enters the pin.
-        QMetaObject::invokeMethod(modem.data(), "unlockRequiredChanged", Qt::QueuedConnection,
-                                  Q_ARG(MMModemLock, modem->unlockRequired()));
+        QMetaObject::invokeMethod(modem.data(), "unlockRequiredChanged", Qt::QueuedConnection, Q_ARG(MMModemLock, modem->unlockRequired()));
     }
 }
 
@@ -121,7 +107,7 @@ void ModemMonitor::requestPin(MMModemLock lock)
         d->dialog = QPointer<PinDialog>(new PinDialog(modem, PinDialog::SimPin2));
     } else if (lock == MM_MODEM_LOCK_SIM_PUK) {
         d->dialog = QPointer<PinDialog>(new PinDialog(modem, PinDialog::SimPuk));
-    } else if (lock == MM_MODEM_LOCK_SIM_PUK2 ) {
+    } else if (lock == MM_MODEM_LOCK_SIM_PUK2) {
         d->dialog = QPointer<PinDialog>(new PinDialog(modem, PinDialog::SimPuk));
     } else if (lock == MM_MODEM_LOCK_PH_SP_PIN) {
         d->dialog = QPointer<PinDialog>(new PinDialog(modem, PinDialog::ModemServiceProviderPin));
@@ -168,16 +154,16 @@ void ModemMonitor::requestPin(MMModemLock lock)
 
         PinDialog::Type type = d->dialog.data()->type();
 
-        if (type == PinDialog::SimPin || type == PinDialog::SimPin2 ||
-            type == PinDialog::ModemServiceProviderPin || type == PinDialog::ModemNetworkPin ||
-            type == PinDialog::ModemPin || type == PinDialog::ModemCorporatePin ||
-            type == PinDialog::ModemPhFsimPin || type == PinDialog::ModemNetworkSubsetPin) {
+        if (type == PinDialog::SimPin || type == PinDialog::SimPin2 //
+            || type == PinDialog::ModemServiceProviderPin || type == PinDialog::ModemNetworkPin //
+            || type == PinDialog::ModemPin || type == PinDialog::ModemCorporatePin //
+            || type == PinDialog::ModemPhFsimPin || type == PinDialog::ModemNetworkSubsetPin) {
             QDBusPendingCall reply = sim->sendPin(d->dialog.data()->pin());
             watcher = new QDBusPendingCallWatcher(reply, sim.data());
-        } else if (type == PinDialog::SimPuk ||
-            type == PinDialog::SimPuk2 || type == PinDialog::ModemServiceProviderPuk ||
-            type == PinDialog::ModemNetworkPuk || type == PinDialog::ModemCorporatePuk ||
-            type == PinDialog::ModemPhFsimPuk || type == PinDialog::ModemNetworkSubsetPuk) {
+        } else if (type == PinDialog::SimPuk //
+                   || type == PinDialog::SimPuk2 || type == PinDialog::ModemServiceProviderPuk //
+                   || type == PinDialog::ModemNetworkPuk || type == PinDialog::ModemCorporatePuk //
+                   || type == PinDialog::ModemPhFsimPuk || type == PinDialog::ModemNetworkSubsetPuk) {
             QDBusPendingCall reply = sim->sendPuk(d->dialog.data()->puk(), d->dialog.data()->pin());
             watcher = new QDBusPendingCallWatcher(reply, sim.data());
         }
@@ -186,21 +172,22 @@ void ModemMonitor::requestPin(MMModemLock lock)
     }
 
 OUT:
-    if(d->dialog) {
+    if (d->dialog) {
         d->dialog.data()->deleteLater();
     }
     d->dialog.clear();
 }
 
-void ModemMonitor::onSendPinArrived(QDBusPendingCallWatcher * watcher)
+void ModemMonitor::onSendPinArrived(QDBusPendingCallWatcher *watcher)
 {
     QDBusPendingReply<> reply = *watcher;
 
     if (reply.isValid()) {
         // Automatically enabling this for cell phones with expensive data plans is not a good idea.
-        //NetworkManager::setWwanEnabled(true);
+        // NetworkManager::setWwanEnabled(true);
     } else {
-        KMessageBox::error(nullptr, i18nc("Text in GSM PIN/PUK unlock error dialog", "Error unlocking modem: %1", reply.error().message()),
+        KMessageBox::error(nullptr,
+                           i18nc("Text in GSM PIN/PUK unlock error dialog", "Error unlocking modem: %1", reply.error().message()),
                            i18nc("Title for GSM PIN/PUK unlock error dialog", "PIN/PUK unlock error"));
     }
 
