@@ -1,37 +1,24 @@
 /*
-    Copyright 2011 Lamarque Souza <lamarque@kde.org>
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2011 Lamarque Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "pindialog.h"
 
-#include <QIntValidator>
 #include <QDesktopWidget>
 #include <QIcon>
+#include <QIntValidator>
 
-#include <KWindowSystem>
 #include <KLocalizedString>
+#include <KWindowSystem>
 
 #include <ModemManagerQt/manager.h>
 
 PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *parent)
-    : QDialog(parent), m_type(type)
+    : QDialog(parent)
+    , m_type(type)
 {
     if (modem) {
         m_udi = modem->uni();
@@ -51,18 +38,18 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     ui->setupUi(this);
     ui->pin->setPasswordMode(true);
 
-    QIntValidator * validator = new QIntValidator(this);
+    QIntValidator *validator = new QIntValidator(this);
     validator->setRange(1000, 99999999);
     ui->pin->setValidator(validator);
     ui->pin2->setValidator(validator);
 
-    QIntValidator * validator2 = new QIntValidator(this);
+    QIntValidator *validator2 = new QIntValidator(this);
     validator2->setRange(10000000, 99999999);
     ui->puk->setValidator(validator2);
 
     ui->errorMessage->setHidden(true);
     QRect desktop = QApplication::desktop()->screenGeometry(topLevelWidget());
-    setMinimumWidth(qMin(1000, qMax(sizeHint().width(), desktop.width() / 4)));
+    setMinimumWidth(360); // width of the PinePhone display
 
     pixmapLabel = new QLabel(this);
     pixmapLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
@@ -93,7 +80,7 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
         setWindowTitle(i18n("%1 unlock required", pukType));
         ui->title->setText(i18n("%1 Unlock Required", pukType));
         ui->prompt->setText(i18n("The mobile broadband device '%1' requires a %2 code before it can be used.", m_name, pukType));
-        ui->pukLabel->setText(i18n("%1 code:",pukType));
+        ui->pukLabel->setText(i18n("%1 code:", pukType));
         ui->pinLabel->setText(i18n("New PIN code:"));
         ui->pin2Label->setText(i18n("Re-enter new PIN code:"));
         ui->chkShowPass->setText(i18n("Show PIN/PUK code"));
@@ -207,7 +194,7 @@ void PinDialog::showErrorMessage(const PinDialog::ErrorCode error)
     ui->pin2Label->setFont(bold);
     ui->pukLabel->setFont(bold);
     bold.setBold(true);
-    switch(error) {
+    switch (error) {
     case PinCodeTooShort:
         msg = i18n("PIN code too short. It should be at least 4 digits.");
         ui->pin->setFocus();
@@ -230,7 +217,6 @@ void PinDialog::showErrorMessage(const PinDialog::ErrorCode error)
     adjustSize();
 }
 
-
 void PinDialog::accept()
 {
     if (isPukDialog()) {
@@ -253,13 +239,13 @@ void PinDialog::accept()
 
 bool PinDialog::isPinDialog() const
 {
-    return (m_type == PinDialog::SimPin ||
-            m_type == PinDialog::SimPin2 ||
-            m_type == PinDialog::ModemServiceProviderPin ||
-            m_type == PinDialog::ModemNetworkPin ||
-            m_type == PinDialog::ModemPin ||
-            m_type == PinDialog::ModemCorporatePin ||
-            m_type == PinDialog::ModemPhFsimPin ||
+    return (m_type == PinDialog::SimPin || //
+            m_type == PinDialog::SimPin2 || //
+            m_type == PinDialog::ModemServiceProviderPin || //
+            m_type == PinDialog::ModemNetworkPin || //
+            m_type == PinDialog::ModemPin || //
+            m_type == PinDialog::ModemCorporatePin || //
+            m_type == PinDialog::ModemPhFsimPin || //
             m_type == PinDialog::ModemNetworkSubsetPin);
 }
 
