@@ -1,21 +1,7 @@
 /*
-Copyright 2011 Lamarque Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2011 Lamarque Souza <lamarque@kde.org>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef PLASMA_NM_PIN_DIALOG_H
@@ -27,8 +13,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QPushButton>
 #include <Solid/Device>
 
-#include <ModemManagerQt/modem.h>
 #include "ui_pinwidget.h"
+#include <ModemManagerQt/modem.h>
 
 class PinWidget;
 
@@ -51,9 +37,9 @@ public:
         ModemPhFsimPin,
         ModemPhFsimPuk,
         ModemNetworkSubsetPin,
-        ModemNetworkSubsetPuk
+        ModemNetworkSubsetPuk,
     };
-    enum ErrorCode {PinCodeTooShort, PinCodesDoNotMatch, PukCodeTooShort};
+    enum ErrorCode { PinCodeTooShort, PinCodesDoNotMatch, PukCodeTooShort };
 
     explicit PinDialog(ModemManager::Modem *modem, const Type type = SimPin, QWidget *parent = nullptr);
     ~PinDialog() override;
@@ -74,8 +60,8 @@ private:
     void showErrorMessage(const PinDialog::ErrorCode);
     bool isPukDialog() const;
     bool isPinDialog() const;
-    Ui::PinWidget * ui;
-    QLabel* pixmapLabel;
+    Ui::PinWidget *ui;
+    QLabel *pixmapLabel;
     QString m_name;
     Type m_type;
     QString m_udi;
