@@ -1,22 +1,8 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "bssidcombobox.h"
@@ -27,12 +13,14 @@
 
 #include <KLocalizedString>
 
-bool signalCompare(const NetworkManager::AccessPoint::Ptr & one, const NetworkManager::AccessPoint::Ptr & two) {
+bool signalCompare(const NetworkManager::AccessPoint::Ptr &one, const NetworkManager::AccessPoint::Ptr &two)
+{
     return one->signalStrength() > two->signalStrength();
 }
 
-BssidComboBox::BssidComboBox(QWidget *parent) :
-    QComboBox(parent), m_dirty(false)
+BssidComboBox::BssidComboBox(QWidget *parent)
+    : QComboBox(parent)
+    , m_dirty(false)
 {
     setEditable(true);
     setInsertPolicy(QComboBox::NoInsert);
@@ -76,7 +64,7 @@ void BssidComboBox::slotCurrentIndexChanged(int)
     Q_EMIT bssidChanged();
 }
 
-void BssidComboBox::init(const QString & bssid, const QString &ssid)
+void BssidComboBox::init(const QString &bssid, const QString &ssid)
 {
     m_initialBssid = bssid;
 
@@ -94,7 +82,8 @@ void BssidComboBox::init(const QString & bssid, const QString &ssid)
             }
 
             for (const NetworkManager::AccessPoint::Ptr &newAp : wifiNetwork->accessPoints()) {
-                bool found = false;;
+                bool found = false;
+                ;
                 for (const NetworkManager::AccessPoint::Ptr &existingAp : aps) {
                     if (newAp->hardwareAddress() == existingAp->hardwareAddress()) {
                         if (newAp->signalStrength() > existingAp->signalStrength()) {
@@ -127,7 +116,7 @@ void BssidComboBox::init(const QString & bssid, const QString &ssid)
     setEditText(m_initialBssid);
 }
 
-void BssidComboBox::addBssidsToCombo(const QList<NetworkManager::AccessPoint::Ptr> & aps)
+void BssidComboBox::addBssidsToCombo(const QList<NetworkManager::AccessPoint::Ptr> &aps)
 {
     clear();
 
@@ -141,7 +130,11 @@ void BssidComboBox::addBssidsToCombo(const QList<NetworkManager::AccessPoint::Pt
             continue;
         }
 
-        const QString text = i18n("%1 (%2%)\nFrequency: %3 Mhz\nChannel: %4", ap->hardwareAddress(), ap->signalStrength(), ap->frequency(), QString::number(NetworkManager::findChannel(ap->frequency())));
+        const QString text = i18n("%1 (%2%)\nFrequency: %3 Mhz\nChannel: %4",
+                                  ap->hardwareAddress(),
+                                  ap->signalStrength(),
+                                  ap->frequency(),
+                                  QString::number(NetworkManager::findChannel(ap->frequency())));
         addItem(text, QVariant::fromValue(ap->hardwareAddress()));
     }
 }
