@@ -1,39 +1,25 @@
 /*
-    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "handler.h"
-#include "connectioneditordialog.h"
 #include "configuration.h"
-#include "uiutils.h"
+#include "connectioneditordialog.h"
 #include "debug.h"
+#include "uiutils.h"
 
-#include <NetworkManagerQt/Manager>
 #include <NetworkManagerQt/AccessPoint>
-#include <NetworkManagerQt/WiredDevice>
-#include <NetworkManagerQt/WirelessDevice>
-#include <NetworkManagerQt/Setting>
-#include <NetworkManagerQt/GsmSetting>
-#include <NetworkManagerQt/WiredSetting>
-#include <NetworkManagerQt/WirelessSetting>
 #include <NetworkManagerQt/ActiveConnection>
+#include <NetworkManagerQt/GsmSetting>
 #include <NetworkManagerQt/Ipv4Setting>
+#include <NetworkManagerQt/Manager>
+#include <NetworkManagerQt/Setting>
+#include <NetworkManagerQt/WiredDevice>
+#include <NetworkManagerQt/WiredSetting>
+#include <NetworkManagerQt/WirelessDevice>
+#include <NetworkManagerQt/WirelessSetting>
 
 #include <libnm/nm-vpn-plugin-info.h>
 
@@ -47,15 +33,15 @@
 #include <QDBusPendingReply>
 #include <QFile>
 #include <QIcon>
+#include <QPointer>
 
-#include <KNotification>
 #include <KLocalizedString>
-#include <KUser>
+#include <KNotification>
+#include <KPluginMetaData>
 #include <KProcess>
-#include <KService>
-#include <KServiceTypeTrader>
-#include <KWindowSystem>
+#include <KUser>
 #include <KWallet>
+#include <KWindowSystem>
 
 #define AGENT_SERVICE "org.kde.kded5"
 #define AGENT_PATH "/modules/networkmanagement"
@@ -70,11 +56,11 @@ Handler::Handler(QObject *parent)
     , m_tmpWwanEnabled(NetworkManager::isWwanEnabled())
 {
     QDBusConnection::sessionBus().connect(QStringLiteral(AGENT_SERVICE),
-                                            QStringLiteral(AGENT_PATH),
-                                            QStringLiteral(AGENT_IFACE),
-                                            QStringLiteral("secretsError"),
-                                            this, SLOT(secretAgentError(QString, QString)));
-
+                                          QStringLiteral(AGENT_PATH),
+                                          QStringLiteral(AGENT_IFACE),
+                                          QStringLiteral("secretsError"),
+                                          this,
+                                          SLOT(secretAgentError(QString, QString)));
 
     if (!Configuration::self().hotspotConnectionPath().isEmpty()) {
         NetworkManager::ActiveConnection::Ptr hotspot = NetworkManager::findActiveConnection(Configuration::self().hotspotConnectionPath());
@@ -95,7 +81,7 @@ Handler::~Handler()
 {
 }
 
-void Handler::activateConnection(const QString& connection, const QString& device, const QString& specificObject)
+void Handler::activateConnection(const QString &connection, const QString &device, const QString &specificObject)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
@@ -112,9 +98,14 @@ void Handler::activateConnection(const QString& connection, const QString& devic
             bool pluginMissing = false;
 
             // Check missing plasma-nm VPN plugin
-            const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin",
-                                                                              QString::fromLatin1("[X-NetworkManager-Services]=='%1'").arg(vpnSetting->serviceType()));
-            pluginMissing = services.isEmpty();
+
+            const auto filter = [vpnSetting](const KPluginMetaData &md) -> bool {
+                return md.value(QStringLiteral("X-NetworkManager-Services")) == vpnSetting->serviceType();
+            };
+
+            const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"), filter);
+
+            pluginMissing = plugins.isEmpty();
 
             // Check missing NetworkManager VPN plugin
             if (!pluginMissing) {
@@ -135,7 +126,6 @@ void Handler::activateConnection(const QString& connection, const QString& devic
                 notification->sendEvent();
                 return;
             }
-
         }
     }
 
@@ -147,9 +137,12 @@ void Handler::activateConnection(const QString& connection, const QString& devic
             if (mmModemDevice) {
                 ModemManager::Modem::Ptr modem = mmModemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                 NetworkManager::GsmSetting::Ptr gsmSetting = con->settings()->setting(NetworkManager::Setting::Gsm).staticCast<NetworkManager::GsmSetting>();
-                if (gsmSetting && gsmSetting->pinFlags() == NetworkManager::Setting::NotSaved &&
-                    modem && modem->unlockRequired() > MM_MODEM_LOCK_NONE) {
-                    QDBusInterface managerIface("org.kde.plasmanetworkmanagement", "/org/kde/plasmanetworkmanagement", "org.kde.plasmanetworkmanagement", QDBusConnection::sessionBus(), this);
+                if (gsmSetting && gsmSetting->pinFlags() == NetworkManager::Setting::NotSaved && modem && modem->unlockRequired() > MM_MODEM_LOCK_NONE) {
+                    QDBusInterface managerIface("org.kde.plasmanetworkmanagement",
+                                                "/org/kde/plasmanetworkmanagement",
+                                                "org.kde.plasmanetworkmanagement",
+                                                QDBusConnection::sessionBus(),
+                                                this);
                     managerIface.call("unlockModem", mmModemDevice->uni());
                     connect(modem.data(), &ModemManager::Modem::unlockRequiredChanged, this, &Handler::unlockRequiredChanged);
                     m_tmpConnectionPath = connection;
@@ -169,36 +162,36 @@ void Handler::activateConnection(const QString& connection, const QString& devic
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
-QString Handler::wifiCode(const QString& connectionPath, const QString& ssid, int _securityType) const
+QString Handler::wifiCode(const QString &connectionPath, const QString &ssid, int _securityType) const
 {
     NetworkManager::WirelessSecurityType securityType = static_cast<NetworkManager::WirelessSecurityType>(_securityType);
 
     QString ret = QStringLiteral("WIFI:S:") + ssid + QLatin1Char(';');
     if (securityType != NetworkManager::NoneSecurity) {
         switch (securityType) {
-            case NetworkManager::NoneSecurity:
-                break;
-            case NetworkManager::StaticWep:
-                ret += "T:WEP;";
-                break;
-            case NetworkManager::WpaPsk:
-            case NetworkManager::Wpa2Psk:
-                ret += "T:WPA;";
-                break;
-            case NetworkManager::SAE:
-                ret += "T:SAE;";
-                break;
-            default:
-            case NetworkManager::DynamicWep:
-            case NetworkManager::WpaEap:
-            case NetworkManager::Wpa2Eap:
-            case NetworkManager::Leap:
-                return {};
+        case NetworkManager::NoneSecurity:
+            break;
+        case NetworkManager::StaticWep:
+            ret += "T:WEP;";
+            break;
+        case NetworkManager::WpaPsk:
+        case NetworkManager::Wpa2Psk:
+            ret += "T:WPA;";
+            break;
+        case NetworkManager::SAE:
+            ret += "T:SAE;";
+            break;
+        default:
+        case NetworkManager::DynamicWep:
+        case NetworkManager::WpaEap:
+        case NetworkManager::Wpa2Eap:
+        case NetworkManager::Leap:
+            return {};
         }
     }
 
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(connectionPath);
-    if(!connection)
+    if (!connection)
         return {};
 
     const auto key = QStringLiteral("802-11-wireless-security");
@@ -207,15 +200,15 @@ QString Handler::wifiCode(const QString& connectionPath, const QString& ssid, in
     const auto secret = reply.argumentAt<0>()[key];
     QString pass;
     switch (securityType) {
-        case NetworkManager::NoneSecurity:
-            break;
-        case NetworkManager::WpaPsk:
-        case NetworkManager::Wpa2Psk:
-        case NetworkManager::SAE:
-            pass = secret["psk"].toString();
-            break;
-        default:
-            return {};
+    case NetworkManager::NoneSecurity:
+        break;
+    case NetworkManager::WpaPsk:
+    case NetworkManager::Wpa2Psk:
+    case NetworkManager::SAE:
+        pass = secret["psk"].toString();
+        break;
+    default:
+        return {};
     }
     if (!pass.isEmpty())
         ret += QStringLiteral("P:") + pass + QLatin1Char(';');
@@ -223,7 +216,7 @@ QString Handler::wifiCode(const QString& connectionPath, const QString& ssid, in
     return ret + QLatin1Char(';');
 }
 
-void Handler::addAndActivateConnection(const QString& device, const QString& specificObject, const QString& password)
+void Handler::addAndActivateConnection(const QString &device, const QString &specificObject, const QString &password)
 {
     NetworkManager::AccessPoint::Ptr ap;
     NetworkManager::WirelessDevice::Ptr wifiDev;
@@ -241,7 +234,8 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         return;
     }
 
-    NetworkManager::ConnectionSettings::Ptr settings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(NetworkManager::ConnectionSettings::Wireless));
+    NetworkManager::ConnectionSettings::Ptr settings =
+        NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(NetworkManager::ConnectionSettings::Wireless));
     settings->setId(ap->ssid());
     settings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
     settings->setAutoconnect(true);
@@ -254,19 +248,25 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
     if (ap->mode() == NetworkManager::AccessPoint::Adhoc) {
         wifiSetting->setMode(NetworkManager::WirelessSetting::Adhoc);
     }
-    NetworkManager::WirelessSecuritySetting::Ptr wifiSecurity = settings->setting(NetworkManager::Setting::WirelessSecurity).dynamicCast<NetworkManager::WirelessSecuritySetting>();
+    NetworkManager::WirelessSecuritySetting::Ptr wifiSecurity =
+        settings->setting(NetworkManager::Setting::WirelessSecurity).dynamicCast<NetworkManager::WirelessSecuritySetting>();
 
-    NetworkManager::WirelessSecurityType securityType = NetworkManager::findBestWirelessSecurity(wifiDev->wirelessCapabilities(), true, (ap->mode() == NetworkManager::AccessPoint::Adhoc), ap->capabilities(), ap->wpaFlags(), ap->rsnFlags());
+    NetworkManager::WirelessSecurityType securityType = NetworkManager::findBestWirelessSecurity(wifiDev->wirelessCapabilities(),
+                                                                                                 true,
+                                                                                                 (ap->mode() == NetworkManager::AccessPoint::Adhoc),
+                                                                                                 ap->capabilities(),
+                                                                                                 ap->wpaFlags(),
+                                                                                                 ap->rsnFlags());
 
     if (securityType != NetworkManager::NoneSecurity) {
         wifiSecurity->setInitialized(true);
         wifiSetting->setSecurity("802-11-wireless-security");
     }
 
-    if (securityType == NetworkManager::Leap ||
-        securityType == NetworkManager::DynamicWep ||
-        securityType == NetworkManager::Wpa2Eap ||
-        securityType == NetworkManager::WpaEap) {
+    if (securityType == NetworkManager::Leap //
+        || securityType == NetworkManager::DynamicWep //
+        || securityType == NetworkManager::Wpa2Eap //
+        || securityType == NetworkManager::WpaEap) {
         if (securityType == NetworkManager::DynamicWep || securityType == NetworkManager::Leap) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Ieee8021x);
             if (securityType == NetworkManager::Leap) {
@@ -283,16 +283,14 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         editor->show();
         KWindowSystem::setState(editor->winId(), NET::KeepAbove);
         KWindowSystem::forceActiveWindow(editor->winId());
-        connect(editor.data(), &ConnectionEditorDialog::accepted,
-                [editor, this] () {
-                    addConnection(editor->setting());
-                });
-        connect(editor.data(), &ConnectionEditorDialog::finished,
-                [editor] () {
-                    if (editor) {
-                        editor->deleteLater();
-                    }
-                });
+        connect(editor.data(), &ConnectionEditorDialog::accepted, [editor, this]() {
+            addConnection(editor->setting());
+        });
+        connect(editor.data(), &ConnectionEditorDialog::finished, [editor]() {
+            if (editor) {
+                editor->deleteLater();
+            }
+        });
         editor->setModal(true);
         editor->show();
     } else {
@@ -323,7 +321,7 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
     settings.clear();
 }
 
-void Handler::addConnection(const NMVariantMapMap& map)
+void Handler::addConnection(const NMVariantMapMap &map)
 {
     QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(map);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
@@ -332,7 +330,7 @@ void Handler::addConnection(const NMVariantMapMap& map)
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
-void Handler::deactivateConnection(const QString& connection, const QString& device)
+void Handler::deactivateConnection(const QString &connection, const QString &device)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
@@ -343,8 +341,7 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
 
     QDBusPendingReply<> reply;
     for (const NetworkManager::ActiveConnection::Ptr &active : NetworkManager::activeConnections()) {
-        if (active->uuid() == con->uuid() && ((!active->devices().isEmpty() && active->devices().first() == device) ||
-                                               active->vpn())) {
+        if (active->uuid() == con->uuid() && ((!active->devices().isEmpty() && active->devices().first() == device) || active->vpn())) {
             if (active->vpn()) {
                 reply = NetworkManager::deactivateConnection(active->path());
             } else {
@@ -392,7 +389,7 @@ void makeDBusCall(const QDBusMessage &message, QObject *context, std::function<v
 {
     QDBusPendingReply<T> reply = QDBusConnection::systemBus().asyncCall(message);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, context);
-    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, context, [func] (QDBusPendingCallWatcher *watcher) {
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, context, [func](QDBusPendingCallWatcher *watcher) {
         const QDBusPendingReply<T> reply = *watcher;
         if (!reply.isValid()) {
             qCWarning(PLASMA_NM) << reply.error().message();
@@ -416,7 +413,7 @@ void setBluetoothEnabled(QString path, bool enabled)
 
 void Handler::enableBluetooth(bool enable)
 {
-    qDBusRegisterMetaType< QMap<QDBusObjectPath, NMVariantMapMap > >();
+    qDBusRegisterMetaType<QMap<QDBusObjectPath, NMVariantMapMap>>();
 
     const QDBusMessage getObjects = QDBusMessage::createMethodCall("org.bluez", "/", "org.freedesktop.DBus.ObjectManager", "GetManagedObjects");
 
@@ -434,10 +431,10 @@ void Handler::enableBluetooth(bool enable)
             // We need to check previous state first
             if (!enable) {
                 QDBusMessage getPowered = QDBusMessage::createMethodCall("org.bluez", objPath, "org.freedesktop.DBus.Properties", "Get");
-                const QList<QVariant> arguments { QLatin1String("org.bluez.Adapter1"), QLatin1String("Powered") };
+                const QList<QVariant> arguments{QLatin1String("org.bluez.Adapter1"), QLatin1String("Powered")};
                 getPowered.setArguments(arguments);
 
-                makeDBusCall<QVariant>(getPowered, this, [objPath, this](const auto reply){
+                makeDBusCall<QVariant>(getPowered, this, [objPath, this](const auto reply) {
                     m_bluetoothAdapters.insert(objPath, reply.value().toBool());
                     setBluetoothEnabled(objPath, false);
                 });
@@ -463,7 +460,7 @@ void Handler::enableWwan(bool enable)
     NetworkManager::setWwanEnabled(enable);
 }
 
-void Handler::removeConnection(const QString& connection)
+void Handler::removeConnection(const QString &connection)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
@@ -487,7 +484,7 @@ void Handler::removeConnection(const QString& connection)
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
-void Handler::updateConnection(const NetworkManager::Connection::Ptr& connection, const NMVariantMapMap& map)
+void Handler::updateConnection(const NetworkManager::Connection::Ptr &connection, const NMVariantMapMap &map)
 {
     QDBusPendingReply<> reply = connection->update(map);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
@@ -526,7 +523,7 @@ void Handler::requestScan(const QString &interface)
                         return;
                     }
                     continue;
-                } else if (m_wirelessScanRetryTimer.contains(interface)){
+                } else if (m_wirelessScanRetryTimer.contains(interface)) {
                     m_wirelessScanRetryTimer.value(interface)->stop();
                     delete m_wirelessScanRetryTimer.take(interface);
                 }
@@ -551,7 +548,8 @@ void Handler::createHotspot()
     NetworkManager::ConnectionSettings::Ptr connectionSettings;
     connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(NetworkManager::ConnectionSettings::Wireless));
 
-    NetworkManager::WirelessSetting::Ptr wifiSetting = connectionSettings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
+    NetworkManager::WirelessSetting::Ptr wifiSetting =
+        connectionSettings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
     wifiSetting->setMode(NetworkManager::WirelessSetting::Adhoc);
     wifiSetting->setSsid(Configuration::self().hotspotName().toUtf8());
 
@@ -586,10 +584,11 @@ void Handler::createHotspot()
     }
 
     wifiSetting->setInitialized(true);
-    wifiSetting->setMode(useApMode ? NetworkManager::WirelessSetting::Ap :NetworkManager::WirelessSetting::Adhoc);
+    wifiSetting->setMode(useApMode ? NetworkManager::WirelessSetting::Ap : NetworkManager::WirelessSetting::Adhoc);
 
     if (!Configuration::self().hotspotPassword().isEmpty()) {
-        NetworkManager::WirelessSecuritySetting::Ptr wifiSecurity = connectionSettings->setting(NetworkManager::Setting::WirelessSecurity).dynamicCast<NetworkManager::WirelessSecuritySetting>();
+        NetworkManager::WirelessSecuritySetting::Ptr wifiSecurity =
+            connectionSettings->setting(NetworkManager::Setting::WirelessSecurity).dynamicCast<NetworkManager::WirelessSecuritySetting>();
         wifiSecurity->setInitialized(true);
 
         if (useApMode) {
@@ -616,9 +615,10 @@ void Handler::createHotspot()
     connectionSettings->setAutoconnect(false);
     connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
-    const QVariantMap options = { {QLatin1String("persist"), QLatin1String("volatile")} };
+    const QVariantMap options = {{QLatin1String("persist"), QLatin1String("volatile")}};
 
-    QDBusPendingReply<QDBusObjectPath, QDBusObjectPath, QVariantMap> reply = NetworkManager::addAndActivateConnection2(connectionSettings->toMap(), wifiDev->uni(), QString(), options);
+    QDBusPendingReply<QDBusObjectPath, QDBusObjectPath, QVariantMap> reply =
+        NetworkManager::addAndActivateConnection2(connectionSettings->toMap(), wifiDev->uni(), QString(), options);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::CreateHotspot);
     watcher->setProperty("connection", Configuration::self().hotspotName());
@@ -658,8 +658,8 @@ bool Handler::checkRequestScanRateLimit(const NetworkManager::WirelessDevice::Pt
     ret |= lastRequestScan.isValid() && lastRequestScan.msecsTo(now) < NM_REQUESTSCAN_LIMIT_RATE;
     // skip the request scan
     if (ret) {
-        qCDebug(PLASMA_NM) << "Last scan finished " << lastScan.msecsTo(now) << "ms ago and last request scan was sent "
-                           << lastRequestScan.msecsTo(now) << "ms ago, Skipping scanning interface:" << wifiDevice->interfaceName();
+        qCDebug(PLASMA_NM) << "Last scan finished " << lastScan.msecsTo(now) << "ms ago and last request scan was sent " << lastRequestScan.msecsTo(now)
+                           << "ms ago, Skipping scanning interface:" << wifiDevice->interfaceName();
         return false;
     }
     return true;
@@ -682,7 +682,6 @@ bool Handler::checkHotspotSupported()
             }
         }
 
-
         if (!wifiFound) {
             return false;
         }
@@ -757,7 +756,7 @@ void Handler::secretAgentError(const QString &connectionPath, const QString &mes
     emit connectionActivationFailed(connectionPath, message);
 }
 
-void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
+void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
 {
     QDBusPendingReply<> reply = *watcher;
     if (reply.isError() || !reply.isValid()) {
@@ -765,43 +764,42 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         QString error = reply.error().message();
         Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
         switch (action) {
-            case Handler::ActivateConnection:
-                notification = new KNotification("FailedToActivateConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to activate %1", watcher->property("connection").toString()));
-                break;
-            case Handler::AddAndActivateConnection:
-                notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to add %1", watcher->property("connection").toString()));
-                break;
-            case Handler::AddConnection:
-                notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to add connection %1", watcher->property("connection").toString()));
-                break;
-            case Handler::DeactivateConnection:
-                notification = new KNotification("FailedToDeactivateConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to deactivate %1", watcher->property("connection").toString()));
-                break;
-            case Handler::RemoveConnection:
-                notification = new KNotification("FailedToRemoveConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
-                break;
-            case Handler::UpdateConnection:
-                notification = new KNotification("FailedToUpdateConnection", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to update connection %1", watcher->property("connection").toString()));
-                break;
-            case Handler::RequestScan:
-            {
-                const QString interface = watcher->property("interface").toString();
-                qCWarning(PLASMA_NM) << "Wireless scan on" << interface << "failed:" << error;
-                scanRequestFailed(interface);
-                break;
-            }
-            case Handler::CreateHotspot:
-                notification = new KNotification("FailedToCreateHotspot", KNotification::CloseOnTimeout, this);
-                notification->setTitle(i18n("Failed to create hotspot %1", watcher->property("connection").toString()));
-                break;
-            default:
-                break;
+        case Handler::ActivateConnection:
+            notification = new KNotification("FailedToActivateConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to activate %1", watcher->property("connection").toString()));
+            break;
+        case Handler::AddAndActivateConnection:
+            notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to add %1", watcher->property("connection").toString()));
+            break;
+        case Handler::AddConnection:
+            notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to add connection %1", watcher->property("connection").toString()));
+            break;
+        case Handler::DeactivateConnection:
+            notification = new KNotification("FailedToDeactivateConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to deactivate %1", watcher->property("connection").toString()));
+            break;
+        case Handler::RemoveConnection:
+            notification = new KNotification("FailedToRemoveConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
+            break;
+        case Handler::UpdateConnection:
+            notification = new KNotification("FailedToUpdateConnection", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to update connection %1", watcher->property("connection").toString()));
+            break;
+        case Handler::RequestScan: {
+            const QString interface = watcher->property("interface").toString();
+            qCWarning(PLASMA_NM) << "Wireless scan on" << interface << "failed:" << error;
+            scanRequestFailed(interface);
+            break;
+        }
+        case Handler::CreateHotspot:
+            notification = new KNotification("FailedToCreateHotspot", KNotification::CloseOnTimeout, this);
+            notification->setTitle(i18n("Failed to create hotspot %1", watcher->property("connection").toString()));
+            break;
+        default:
+            break;
         }
 
         if (notification) {
@@ -815,23 +813,23 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
 
         switch (action) {
-            case Handler::AddConnection:
-                notification = new KNotification("ConnectionAdded", KNotification::CloseOnTimeout, this);
-                notification->setText(i18n("Connection %1 has been added", watcher->property("connection").toString()));
-                break;
-            case Handler::RemoveConnection:
-                notification = new KNotification("ConnectionRemoved", KNotification::CloseOnTimeout, this);
-                notification->setText(i18n("Connection %1 has been removed", watcher->property("connection").toString()));
-                break;
-            case Handler::UpdateConnection:
-                notification = new KNotification("ConnectionUpdated", KNotification::CloseOnTimeout, this);
-                notification->setText(i18n("Connection %1 has been updated", watcher->property("connection").toString()));
-                break;
-            case Handler::RequestScan:
-                qCDebug(PLASMA_NM) << "Wireless scan on" << watcher->property("interface").toString() << "succeeded";
-                break;
-            default:
-                break;
+        case Handler::AddConnection:
+            notification = new KNotification("ConnectionAdded", KNotification::CloseOnTimeout, this);
+            notification->setText(i18n("Connection %1 has been added", watcher->property("connection").toString()));
+            break;
+        case Handler::RemoveConnection:
+            notification = new KNotification("ConnectionRemoved", KNotification::CloseOnTimeout, this);
+            notification->setText(i18n("Connection %1 has been removed", watcher->property("connection").toString()));
+            break;
+        case Handler::UpdateConnection:
+            notification = new KNotification("ConnectionUpdated", KNotification::CloseOnTimeout, this);
+            notification->setText(i18n("Connection %1 has been updated", watcher->property("connection").toString()));
+            break;
+        case Handler::RequestScan:
+            qCDebug(PLASMA_NM) << "Wireless scan on" << watcher->property("interface").toString() << "succeeded";
+            break;
+        default:
+            break;
         }
 
         if (notification) {
@@ -864,7 +862,7 @@ void Handler::hotspotCreated(QDBusPendingCallWatcher *watcher)
             return;
         }
 
-        connect(hotspot.data(), &NetworkManager::ActiveConnection::stateChanged, [=] (NetworkManager::ActiveConnection::State state) {
+        connect(hotspot.data(), &NetworkManager::ActiveConnection::stateChanged, [=](NetworkManager::ActiveConnection::State state) {
             if (state > NetworkManager::ActiveConnection::Activated) {
                 Configuration::self().setHotspotConnectionPath(QString());
                 Q_EMIT hotspotDisabled();
@@ -890,4 +888,3 @@ void Handler::unlockRequiredChanged(MMModemLock modemLock)
     }
 }
 #endif
-
