@@ -1,26 +1,12 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "openswanwidget.h"
-#include "ui_openswan.h"
 #include "nm-openswan-service.h"
+#include "ui_openswan.h"
 
 #include <NetworkManagerQt/Setting>
 
@@ -73,7 +59,8 @@ void OpenswanWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
         m_ui->groupname->setText(groupName);
     }
 
-    const NetworkManager::Setting::SecretFlags groupPasswordFlag = static_cast<NetworkManager::Setting::SecretFlags>(data.value(NM_OPENSWAN_PSK_VALUE"-flags").toInt());
+    const NetworkManager::Setting::SecretFlags groupPasswordFlag =
+        static_cast<NetworkManager::Setting::SecretFlags>(data.value(NM_OPENSWAN_PSK_VALUE "-flags").toInt());
     if (groupPasswordFlag == NetworkManager::Setting::None) {
         m_ui->groupPassword->setPasswordOption(PasswordField::StoreForAllUsers);
     } else if (groupPasswordFlag == NetworkManager::Setting::AgentOwned) {
@@ -82,7 +69,8 @@ void OpenswanWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
         m_ui->groupPassword->setPasswordOption(PasswordField::AlwaysAsk);
     }
 
-    const NetworkManager::Setting::SecretFlags userPasswordFlag = static_cast<NetworkManager::Setting::SecretFlags>(data.value(NM_OPENSWAN_XAUTH_PASSWORD"-flags").toInt());
+    const NetworkManager::Setting::SecretFlags userPasswordFlag =
+        static_cast<NetworkManager::Setting::SecretFlags>(data.value(NM_OPENSWAN_XAUTH_PASSWORD "-flags").toInt());
     if (userPasswordFlag == NetworkManager::Setting::None) {
         m_ui->userPassword->setPasswordOption(PasswordField::StoreForAllUsers);
     } else if (userPasswordFlag == NetworkManager::Setting::AgentOwned) {
@@ -154,12 +142,12 @@ QVariantMap OpenswanWidget::setting() const
 
     if (m_ui->userPassword->passwordOption() == PasswordField::StoreForAllUsers) {
         data.insert(NM_OPENSWAN_XAUTH_PASSWORD_INPUT_MODES, NM_OPENSWAN_PW_TYPE_SAVE);
-        data.insert(NM_OPENSWAN_XAUTH_PASSWORD"-flags", QString::number(NetworkManager::Setting::None));
+        data.insert(NM_OPENSWAN_XAUTH_PASSWORD "-flags", QString::number(NetworkManager::Setting::None));
     } else if (m_ui->userPassword->passwordOption() == PasswordField::StoreForUser) {
-        data.insert(NM_OPENSWAN_XAUTH_PASSWORD"-flags", QString::number(NetworkManager::Setting::AgentOwned));
+        data.insert(NM_OPENSWAN_XAUTH_PASSWORD "-flags", QString::number(NetworkManager::Setting::AgentOwned));
     } else {
         data.insert(NM_OPENSWAN_XAUTH_PASSWORD_INPUT_MODES, NM_OPENSWAN_PW_TYPE_ASK);
-        data.insert(NM_OPENSWAN_XAUTH_PASSWORD"-flags", QString::number(NetworkManager::Setting::NotSaved));
+        data.insert(NM_OPENSWAN_XAUTH_PASSWORD "-flags", QString::number(NetworkManager::Setting::NotSaved));
     }
 
     if (!m_ui->groupPassword->text().isEmpty()) {
@@ -168,12 +156,12 @@ QVariantMap OpenswanWidget::setting() const
 
     if (m_ui->groupPassword->passwordOption() == PasswordField::StoreForAllUsers) {
         data.insert(NM_OPENSWAN_PSK_INPUT_MODES, NM_OPENSWAN_PW_TYPE_SAVE);
-        data.insert(NM_OPENSWAN_PSK_VALUE"-flags", QString::number(NetworkManager::Setting::None));
+        data.insert(NM_OPENSWAN_PSK_VALUE "-flags", QString::number(NetworkManager::Setting::None));
     } else if (m_ui->groupPassword->passwordOption() == PasswordField::StoreForUser) {
-        data.insert(NM_OPENSWAN_PSK_VALUE"-flags", QString::number(NetworkManager::Setting::AgentOwned));
+        data.insert(NM_OPENSWAN_PSK_VALUE "-flags", QString::number(NetworkManager::Setting::AgentOwned));
     } else {
         data.insert(NM_OPENSWAN_PSK_INPUT_MODES, NM_OPENSWAN_PW_TYPE_ASK);
-        data.insert(NM_OPENSWAN_PSK_VALUE"-flags", QString::number(NetworkManager::Setting::NotSaved));
+        data.insert(NM_OPENSWAN_PSK_VALUE "-flags", QString::number(NetworkManager::Setting::NotSaved));
     }
 
     if (!m_ui->username->text().isEmpty()) {
