@@ -1,34 +1,20 @@
 /*
-    Copyright 2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2015 Jan Grulich <jgrulich@redhat.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "sshwidget.h"
 
-#include "ui_sshwidget.h"
 #include "ui_sshadvanced.h"
+#include "ui_sshwidget.h"
 
 #include "simpleipv4addressvalidator.h"
 #include "simpleipv6addressvalidator.h"
 
-#include <QString>
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <QString>
 
 #include "nm-ssh-service.h"
 
@@ -63,7 +49,7 @@ SshSettingWidget::SshSettingWidget(const NetworkManager::VpnSetting::Ptr &settin
     QVBoxLayout *layout = new QVBoxLayout(d->advancedDlg);
     layout->addWidget(d->advancedWid);
     d->advancedDlg->setLayout(layout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, d->advancedDlg);
+    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, d->advancedDlg);
     connect(buttons, &QDialogButtonBox::accepted, d->advancedDlg, &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, d->advancedDlg, &QDialog::reject);
 
@@ -162,7 +148,7 @@ void SshSettingWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
         d->ui.cmb_authType->setCurrentIndex(0);
     } else if (sshAuthType == QLatin1String(NM_SSH_AUTH_TYPE_PASSWORD)) {
         d->ui.cmb_authType->setCurrentIndex(1);
-        const NetworkManager::Setting::SecretFlags type = (NetworkManager::Setting::SecretFlags)dataMap[NM_SSH_KEY_PASSWORD"-flags"].toInt();
+        const NetworkManager::Setting::SecretFlags type = (NetworkManager::Setting::SecretFlags)dataMap[NM_SSH_KEY_PASSWORD "-flags"].toInt();
         fillOnePasswordCombo(d->ui.le_password, type);
     } else if (sshAuthType == QLatin1String(NM_SSH_AUTH_TYPE_KEY)) {
         d->ui.cmb_authType->setCurrentIndex(2);
@@ -242,7 +228,7 @@ QVariantMap SshSettingWidget::setting() const
     NMStringMap data;
     NMStringMap secretData;
 
-    data.insert(QLatin1String(NM_SSH_KEY_REMOTE),  d->ui.le_gateway->text());
+    data.insert(QLatin1String(NM_SSH_KEY_REMOTE), d->ui.le_gateway->text());
 
     if (!d->ui.le_remoteIp->text().isEmpty()) {
         data.insert(QLatin1String(NM_SSH_KEY_REMOTE_IP), d->ui.le_remoteIp->text());
@@ -273,22 +259,22 @@ QVariantMap SshSettingWidget::setting() const
     }
 
     switch (d->ui.cmb_authType->currentIndex()) {
-        case 0:
-            data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_SSH_AGENT));
-            break;
-        case 1:
-            data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_PASSWORD));
-            if (!d->ui.le_password->text().isEmpty()) {
-                secretData.insert(QLatin1String(NM_SSH_KEY_PASSWORD), d->ui.le_password->text());
-            }
-            handleOnePasswordType(d->ui.le_password, NM_SSH_KEY_PASSWORD"-flags", data);
-            break;
-        case 2:
-            data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_KEY));
-            if (!d->ui.kurl_sshKeyFile->url().isEmpty()) {
-                data.insert(QLatin1String(NM_SSH_KEY_KEY_FILE), d->ui.kurl_sshKeyFile->url().toLocalFile());
-            }
-            break;
+    case 0:
+        data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_SSH_AGENT));
+        break;
+    case 1:
+        data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_PASSWORD));
+        if (!d->ui.le_password->text().isEmpty()) {
+            secretData.insert(QLatin1String(NM_SSH_KEY_PASSWORD), d->ui.le_password->text());
+        }
+        handleOnePasswordType(d->ui.le_password, NM_SSH_KEY_PASSWORD "-flags", data);
+        break;
+    case 2:
+        data.insert(QLatin1String(NM_SSH_KEY_AUTH_TYPE), QLatin1String(NM_SSH_AUTH_TYPE_KEY));
+        if (!d->ui.kurl_sshKeyFile->url().isEmpty()) {
+            data.insert(QLatin1String(NM_SSH_KEY_KEY_FILE), d->ui.kurl_sshKeyFile->url().toLocalFile());
+        }
+        break;
     }
 
     if (d->advUi.chk_useCustomGatewayPort->isChecked()) {
@@ -389,6 +375,6 @@ bool SshSettingWidget::isValid() const
 {
     Q_D(const SshSettingWidget);
 
-    return !d->ui.le_gateway->text().isEmpty() && !d->ui.le_localIp->text().isEmpty() &&
-           !d->ui.le_remoteIp->text().isEmpty() && !d->ui.le_netmask->text().isEmpty();
+    return !d->ui.le_gateway->text().isEmpty() && !d->ui.le_localIp->text().isEmpty() && !d->ui.le_remoteIp->text().isEmpty()
+        && !d->ui.le_netmask->text().isEmpty();
 }
